import {
  select,csv,scaleLinear,scaleTime,extent,axisLeft,axisBottom,line,max
} from 'd3';
//importing some attributes from d3
const svg = select('svg'); 

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
  const title = 'Global Video Games sales from 2003 to 2014 '; // for the title
  
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year'; 

  const yValue = d => d.GlobalSales; 
  const yAxisLabel = 'Global sales (in millions )'; 
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
 
  
  const xScale = scaleTime()
  
    .domain(extent(data, xValue)) 
    .range([0,innerWidth]) 
    .nice(); // for rounding the values
  
  const yScale = scaleLinear() // 
    .domain([0, max(data, yValue )])
    .range([innerHeight,0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight) // to get axis position at bottom
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth) // to get axis position at left side
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis); //for appending a 'g' element to the SVG. g element is used to group SVG shapes together,
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text') 
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 8)
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text') // for x axis labeling
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  


  
  const lineGenerator = line() // for making horizontal and vertical lines for x and y axis
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path') // provides path to the line 
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text') // for labeling the title
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
// getting the csv data from my gist
csv('https://gist.githubusercontent.com/Tejamod/9bfe1c6f620412eb3e3c329fe062ae54/raw/b76bb35eeff445a16dfe73e89d621f3e9adfe9b8/vgsalessmall.csv')
  .then(data => {
  	
    data.forEach(d => {
    	d.GlobalSales = +d.GlobalSales;
      d.Year = new Date(d.Year);
    });
  
  
  console.log(data)
    render(data);
  });